==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/companies_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::CompaniesController < CoreModelsController
    # GET /people_and_companies/companies
    # GET /people_and_companies/companies.json
    def index
      @people_and_companies_companies = PeopleAndCompanies::Company.all.order('id')

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_companies }
      end
    end

    # GET /people_and_companies/companies/1
    # GET /people_and_companies/companies/1.json
    def show
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_company }
      end
    end

    # GET /people_and_companies/companies/new
    # GET /people_and_companies/companies/new.json
    def new
      @people_and_companies_company = PeopleAndCompanies::Company.new
      @people_and_companies_company.build_company_logo
      @people_and_companies_company.company_logo.build_logo

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_company }
      end
    end

    # GET /people_and_companies/companies/1/edit
    def edit
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])

      if @people_and_companies_company.logo.nil?
        @people_and_companies_company.build_company_logo
        @people_and_companies_company.company_logo.build_logo
      end
    end

    # POST /people_and_companies/companies
    # POST /people_and_companies/companies.json
    def create
      @people_and_companies_company = PeopleAndCompanies::Company.new(params[:people_and_companies_company])

      respond_to do |format|
        if @people_and_companies_company.save
          format.html { redirect_to @people_and_companies_company, :notice => 'Company was successfully created.' }
          format.json { render :json => @people_and_companies_company, :status => :created, :location => @people_and_companies_company }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/companies/1
    # PUT /people_and_companies/companies/1.json
    def update
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])

      respond_to do |format|
        if @people_and_companies_company.update_attributes(params[:people_and_companies_company])
          format.html { redirect_to @people_and_companies_company, :notice => 'Company was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/companies/1
    # DELETE /people_and_companies/companies/1.json
    def destroy
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])
      @people_and_companies_company.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_companies_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/companies_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::CompaniesController < CoreModelsController
    # GET /people_and_companies/companies
    # GET /people_and_companies/companies.json
    def index
      @people_and_companies_companies = PeopleAndCompanies::Company.all.order('id')

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_companies }
      end
    end

    # GET /people_and_companies/companies/1
    # GET /people_and_companies/companies/1.json
    def show
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_company }
      end
    end

    # GET /people_and_companies/companies/new
    # GET /people_and_companies/companies/new.json
    def new
      @people_and_companies_company = PeopleAndCompanies::Company.new
      @people_and_companies_company.build_company_logo
      @people_and_companies_company.company_logo.build_logo

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_company }
      end
    end

    # GET /people_and_companies/companies/1/edit
    def edit
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])

      if @people_and_companies_company.logo.nil?
        @people_and_companies_company.build_company_logo
        @people_and_companies_company.company_logo.build_logo
      end
    end

    # POST /people_and_companies/companies
    # POST /people_and_companies/companies.json
    def create
      @people_and_companies_company = PeopleAndCompanies::Company.new(params[:people_and_companies_company])

      respond_to do |format|
        if @people_and_companies_company.save
          format.html { redirect_to @people_and_companies_company, :notice => 'Company was successfully created.' }
          format.json { render :json => @people_and_companies_company, :status => :created, :location => @people_and_companies_company }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/companies/1
    # PUT /people_and_companies/companies/1.json
    def update
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])

      respond_to do |format|
        if @people_and_companies_company.update(params[:people_and_companies_company])
          format.html { redirect_to @people_and_companies_company, :notice => 'Company was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_company.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/companies/1
    # DELETE /people_and_companies/companies/1.json
    def destroy
      @people_and_companies_company = PeopleAndCompanies::Company.find(params[:id])
      @people_and_companies_company.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_companies_url }
        format.json { head :no_content }
      end
    end
  end
end
